CancelTimer

Struct CancelTimer 

pub struct CancelTimer(/* private fields */);
Implementation of CancellationTrigger that is canceled once the specified Duration elapsed. The “timer” is started immediately upon creation.

See also on_timeout.

Logging

  • [trace] Every time a timer is started or elapsed (i.e., upon cancellation).
  • [warn] If the timer is dropped, but the timer thread cannot be safely destroyed.

Implementations

Source

impl CancelTimer

pub fn start(duration: Duration) -> Self

Create a new CancelTimer that will be canceled once the given duration elapsed.