pub struct CancelChain(/* private fields */);Expand description
Implementation of CancellationTrigger which chains together several
trigger implementations.
This is mostly used internally by crate::on_trigger to implement chaining of
multiple cancellation scopes. However, it is still a normal CancellationTrigger and
thus can be used to combine triggers manually as well.
Implementations
Sourceimpl CancelChain
impl CancelChain
Sourcepub fn pop(&mut self) -> Option<DynamicCancellationTrigger>
pub fn pop(&mut self) -> Option<DynamicCancellationTrigger>
Remove the first trigger in the chain.
Sourcepub fn push<T: CancellationTrigger + 'static>(&mut self, trigger: T)
pub fn push<T: CancellationTrigger + 'static>(&mut self, trigger: T)
Add a new cancellation trigger. The new chain starts with the given trigger and continues with the already present ones.
Sourcepub fn clone_and_flatten(&self) -> DynamicCancellationTrigger
pub fn clone_and_flatten(&self) -> DynamicCancellationTrigger
Make a copy of this trigger chain, but if the chain is empty or only has a single element, replace it with a simplified trigger which does not need vector traversal.